/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

/*
 * NOTICE: Do not edit this file manually.
 * This file is automatically generated by the OpenAPI Generator, @kbn/openapi-generator.
 *
 * info:
 *   title: Common Conversation Attributes
 *   version: not applicable
 */

import { z } from '@kbn/zod';

import { NonEmptyString, User } from '../common_attributes.gen';

/**
 * trace Data
 */
export type TraceData = z.infer<typeof TraceData>;
export const TraceData = z.object({
  /**
   * Could be any string, not necessarily a UUID
   */
  transactionId: z.string().optional(),
  /**
   * Could be any string, not necessarily a UUID
   */
  traceId: z.string().optional(),
});

/**
 * The basis of a content reference
 */
export type BaseContentReference = z.infer<typeof BaseContentReference>;
export const BaseContentReference = z.object({
  /**
   * Id of the content reference
   */
  id: z.string(),
  /**
   * Type of the content reference
   */
  type: z.string(),
});

/**
 * References a knowledge base entry
 */
export type KnowledgeBaseEntryContentReference = z.infer<typeof KnowledgeBaseEntryContentReference>;
export const KnowledgeBaseEntryContentReference = BaseContentReference.merge(
  z.object({
    type: z.literal('KnowledgeBaseEntry'),
    /**
     * Id of the Knowledge Base Entry
     */
    knowledgeBaseEntryId: z.string(),
    /**
     * Name of the knowledge base entry
     */
    knowledgeBaseEntryName: z.string(),
  })
);

/**
 * References an ESQL query
 */
export type EsqlContentReference = z.infer<typeof EsqlContentReference>;
export const EsqlContentReference = BaseContentReference.merge(
  z.object({
    type: z.literal('EsqlQuery'),
    /**
     * An ESQL query
     */
    query: z.string(),
    /**
     * Label of the query
     */
    label: z.string(),
    /**
     * Time range to select in the time picker.
     */
    timerange: z
      .object({
        from: z.string(),
        to: z.string(),
      })
      .optional(),
  })
);

/**
 * References a security alert
 */
export type SecurityAlertContentReference = z.infer<typeof SecurityAlertContentReference>;
export const SecurityAlertContentReference = BaseContentReference.merge(
  z.object({
    type: z.literal('SecurityAlert'),
    /**
     * ID of the Alert
     */
    alertId: z.string(),
  })
);

/**
 * References the security alerts page
 */
export type SecurityAlertsPageContentReference = z.infer<typeof SecurityAlertsPageContentReference>;
export const SecurityAlertsPageContentReference = BaseContentReference.merge(
  z.object({
    type: z.literal('SecurityAlertsPage'),
  })
);

/**
 * References the product documentation
 */
export type ProductDocumentationContentReference = z.infer<
  typeof ProductDocumentationContentReference
>;
export const ProductDocumentationContentReference = BaseContentReference.merge(
  z.object({
    type: z.literal('ProductDocumentation'),
    /**
     * Title of the documentation
     */
    title: z.string(),
    /**
     * URL to the documentation
     */
    url: z.string(),
  })
);

/**
 * A content reference
 */
export const ContentReferenceInternal = z.union([
  KnowledgeBaseEntryContentReference,
  SecurityAlertContentReference,
  SecurityAlertsPageContentReference,
  ProductDocumentationContentReference,
  EsqlContentReference,
]);

export type ContentReference = z.infer<typeof ContentReferenceInternal>;
export const ContentReference = ContentReferenceInternal as z.ZodType<ContentReference>;

/**
 * A union of all content reference types
 */
export type ContentReferences = z.infer<typeof ContentReferences>;
export const ContentReferences = z
  .object({})
  .catchall(
    z.union([
      KnowledgeBaseEntryContentReference,
      SecurityAlertContentReference,
      SecurityAlertsPageContentReference,
      ProductDocumentationContentReference,
      EsqlContentReference,
    ])
  );

/**
 * Message metadata
 */
export type MessageMetadata = z.infer<typeof MessageMetadata>;
export const MessageMetadata = z.object({
  /**
   * Data refered to by the message content.
   */
  contentReferences: ContentReferences.optional(),
});

/**
 * Replacements object used to anonymize/deanomymize messsages
 */
export type Replacements = z.infer<typeof Replacements>;
export const Replacements = z.object({}).catchall(z.string());

export type Reader = z.infer<typeof Reader>;
export const Reader = z.object({}).catchall(z.unknown());

/**
 * Provider
 */
export type Provider = z.infer<typeof Provider>;
export const Provider = z.enum(['OpenAI', 'Azure OpenAI', 'Other']);
export type ProviderEnum = typeof Provider.enum;
export const ProviderEnum = Provider.enum;

/**
 * Message role.
 */
export type MessageRole = z.infer<typeof MessageRole>;
export const MessageRole = z.enum(['system', 'user', 'assistant']);
export type MessageRoleEnum = typeof MessageRole.enum;
export const MessageRoleEnum = MessageRole.enum;

/**
 * The conversation category.
 */
export type ConversationCategory = z.infer<typeof ConversationCategory>;
export const ConversationCategory = z.enum(['assistant', 'insights']);
export type ConversationCategoryEnum = typeof ConversationCategory.enum;
export const ConversationCategoryEnum = ConversationCategory.enum;

/**
 * The conversation confidence.
 */
export type ConversationConfidence = z.infer<typeof ConversationConfidence>;
export const ConversationConfidence = z.enum(['low', 'medium', 'high']);
export type ConversationConfidenceEnum = typeof ConversationConfidence.enum;
export const ConversationConfidenceEnum = ConversationConfidence.enum;

/**
 * AI assistant conversation message.
 */
export type Message = z.infer<typeof Message>;
export const Message = z.object({
  /**
   * Message content.
   */
  content: z.string(),
  /**
   * Message content.
   */
  reader: Reader.optional(),
  /**
   * Message role.
   */
  role: MessageRole,
  /**
   * The timestamp message was sent or received.
   */
  timestamp: NonEmptyString,
  /**
   * Is error message.
   */
  isError: z.boolean().optional(),
  /**
   * trace Data
   */
  traceData: TraceData.optional(),
  /**
   * metadata
   */
  metadata: MessageMetadata.optional(),
});

export type ApiConfig = z.infer<typeof ApiConfig>;
export const ApiConfig = z.object({
  /**
   * connector id
   */
  connectorId: z.string(),
  /**
   * action type id
   */
  actionTypeId: z.string(),
  /**
   * defaultSystemPromptId
   */
  defaultSystemPromptId: z.string().optional(),
  /**
   * Provider
   */
  provider: Provider.optional(),
  /**
   * model
   */
  model: z.string().optional(),
});

export type ConversationSummary = z.infer<typeof ConversationSummary>;
export const ConversationSummary = z.object({
  /**
   * Summary text of the conversation over time.
   */
  content: z.string().optional(),
  /**
   * The timestamp summary was updated.
   */
  timestamp: NonEmptyString.optional(),
  /**
   * Define if summary is marked as publicly available.
   */
  public: z.boolean().optional(),
  /**
   * How confident you are about this being a correct and useful learning.
   */
  confidence: ConversationConfidence.optional(),
});

export type ErrorSchema = z.infer<typeof ErrorSchema>;
export const ErrorSchema = z
  .object({
    id: NonEmptyString.optional(),
    error: z.object({
      status_code: z.number().int().min(400),
      message: z.string(),
    }),
  })
  .strict();

export type ConversationResponse = z.infer<typeof ConversationResponse>;
export const ConversationResponse = z.object({
  id: NonEmptyString,
  /**
   * The conversation title.
   */
  title: z.string(),
  /**
   * The conversation category.
   */
  category: ConversationCategory,
  summary: ConversationSummary.optional(),
  timestamp: NonEmptyString.optional(),
  /**
   * The last time conversation was updated.
   */
  updatedAt: z.string().optional(),
  /**
   * The time conversation was created.
   */
  createdAt: z.string(),
  replacements: Replacements.optional(),
  users: z.array(User),
  /**
   * The conversation messages.
   */
  messages: z.array(Message).optional(),
  /**
   * LLM API configuration.
   */
  apiConfig: ApiConfig.optional(),
  /**
   * excludeFromLastConversationStorage.
   */
  excludeFromLastConversationStorage: z.boolean().optional(),
  /**
   * Kibana space
   */
  namespace: z.string(),
});

export type ConversationUpdateProps = z.infer<typeof ConversationUpdateProps>;
export const ConversationUpdateProps = z.object({
  id: NonEmptyString,
  /**
   * The conversation title.
   */
  title: z.string().optional(),
  /**
   * The conversation category.
   */
  category: ConversationCategory.optional(),
  /**
   * The conversation messages.
   */
  messages: z.array(Message).optional(),
  /**
   * LLM API configuration.
   */
  apiConfig: ApiConfig.optional(),
  summary: ConversationSummary.optional(),
  /**
   * excludeFromLastConversationStorage.
   */
  excludeFromLastConversationStorage: z.boolean().optional(),
  replacements: Replacements.optional(),
});

export type ConversationCreateProps = z.infer<typeof ConversationCreateProps>;
export const ConversationCreateProps = z.object({
  /**
   * The conversation id.
   */
  id: z.string().optional(),
  /**
   * The conversation title.
   */
  title: z.string(),
  /**
   * The conversation category.
   */
  category: ConversationCategory.optional(),
  /**
   * The conversation messages.
   */
  messages: z.array(Message).optional(),
  /**
   * LLM API configuration.
   */
  apiConfig: ApiConfig.optional(),
  /**
   * excludeFromLastConversationStorage.
   */
  excludeFromLastConversationStorage: z.boolean().optional(),
  replacements: Replacements.optional(),
});

export type ConversationMessageCreateProps = z.infer<typeof ConversationMessageCreateProps>;
export const ConversationMessageCreateProps = z.object({
  /**
   * The conversation messages.
   */
  messages: z.array(Message),
});
