/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import React, { ReactNode, MouseEventHandler } from 'react';
import PropTypes from 'prop-types';
import { EuiButtonIcon, EuiFlexGroup, EuiFlexItem, EuiToolTip } from '@elastic/eui';
import { i18n } from '@kbn/i18n';

import { TooltipIcon, IconType } from '../tooltip_icon';

const strings = {
  getRemoveAriaLabel: () =>
    i18n.translate('xpack.canvas.argFormArgSimpleForm.removeAriaLabel', {
      defaultMessage: 'Remove',
    }),
  getRequiredTooltip: () =>
    i18n.translate('xpack.canvas.argFormArgSimpleForm.requiredTooltip', {
      defaultMessage: 'This argument is required, you should specify a value.',
    }),
};
interface Props {
  children?: ReactNode;
  required?: boolean;
  valueMissing?: boolean;
  onRemove: MouseEventHandler<HTMLAnchorElement>;
}

// This is what is being generated by render() from the Arg class. It is called in FunctionForm
export const ArgSimpleForm: React.FunctionComponent<Props> = ({
  children,
  required,
  valueMissing,
  onRemove,
}) => {
  return (
    <EuiFlexGroup alignItems="center" gutterSize="s" className="canvasArg__form">
      <EuiFlexItem>{children}</EuiFlexItem>
      {valueMissing && (
        <EuiFlexItem grow={false}>
          <TooltipIcon
            position="left"
            icon={IconType.error}
            content={strings.getRequiredTooltip()}
          />
        </EuiFlexItem>
      )}

      {!required && (
        <EuiToolTip position="top" content={strings.getRemoveAriaLabel()}>
          <EuiButtonIcon
            color="text"
            onClick={onRemove}
            iconType="cross"
            iconSize="s"
            aria-label={strings.getRemoveAriaLabel()}
            className="canvasArg__remove"
          />
        </EuiToolTip>
      )}
    </EuiFlexGroup>
  );
};

ArgSimpleForm.propTypes = {
  children: PropTypes.node,
  required: PropTypes.bool,
  valueMissing: PropTypes.bool,
  onRemove: PropTypes.func.isRequired,
};
