/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { useState } from 'react';

import type { PostTransformsPreviewRequestSchema } from '../../../../../../../server/routes/api_schemas/transforms';

import type { StepDefineExposedState } from '../common';

export const useAdvancedSourceEditor = (
  defaults: StepDefineExposedState,
  previewRequest: PostTransformsPreviewRequestSchema
) => {
  const stringifiedSourceConfig = JSON.stringify(previewRequest.source.query, null, 2);

  // Advanced editor for source config state
  const [sourceConfigUpdated, setSourceConfigUpdated] = useState(defaults.sourceConfigUpdated);

  const [isAdvancedSourceEditorSwitchModalVisible, setAdvancedSourceEditorSwitchModalVisible] =
    useState(false);

  const [isAdvancedSourceEditorEnabled, setAdvancedSourceEditorEnabled] = useState(
    defaults.isAdvancedSourceEditorEnabled
  );

  const [isAdvancedSourceEditorApplyButtonEnabled, setAdvancedSourceEditorApplyButtonEnabled] =
    useState(false);

  const [advancedEditorSourceConfigLastApplied, setAdvancedEditorSourceConfigLastApplied] =
    useState(stringifiedSourceConfig);

  const [advancedEditorSourceConfig, setAdvancedEditorSourceConfig] =
    useState(stringifiedSourceConfig);

  const applyAdvancedSourceEditorChanges = () => {
    const sourceConfig = JSON.parse(advancedEditorSourceConfig);
    const prettySourceConfig = JSON.stringify(sourceConfig, null, 2);
    setSourceConfigUpdated(true);
    setAdvancedEditorSourceConfig(prettySourceConfig);
    setAdvancedEditorSourceConfigLastApplied(prettySourceConfig);
    setAdvancedSourceEditorApplyButtonEnabled(false);
  };

  // If switching to KQL after updating via editor - reset search
  const toggleAdvancedSourceEditor = (reset = false) => {
    if (reset === true) {
      setSourceConfigUpdated(false);
    }
    if (isAdvancedSourceEditorEnabled === false) {
      setAdvancedEditorSourceConfigLastApplied(advancedEditorSourceConfig);
    }

    setAdvancedSourceEditorEnabled(!isAdvancedSourceEditorEnabled);
    setAdvancedSourceEditorApplyButtonEnabled(false);
  };

  return {
    actions: {
      applyAdvancedSourceEditorChanges,
      setAdvancedSourceEditorApplyButtonEnabled,
      setAdvancedSourceEditorEnabled,
      setAdvancedEditorSourceConfig,
      setAdvancedEditorSourceConfigLastApplied,
      setAdvancedSourceEditorSwitchModalVisible,
      setSourceConfigUpdated,
      toggleAdvancedSourceEditor,
    },
    state: {
      advancedEditorSourceConfig,
      advancedEditorSourceConfigLastApplied,
      isAdvancedSourceEditorApplyButtonEnabled,
      isAdvancedSourceEditorEnabled,
      isAdvancedSourceEditorSwitchModalVisible,
      sourceConfigUpdated,
    },
  };
};
