/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { ReactNode } from 'react';
import type { SnakeToCamelCase } from '../../../common/types';
import type { SettingsUserAction } from '../../../common/types/domain';
import type { UserActionBuilder } from './types';

import { createCommonUpdateUserActionBuilder } from './common';
import { DISABLED_SETTING, ENABLED_SETTING, SYNC_ALERTS_LC } from './translations';

function getSettingsLabel(userAction: SnakeToCamelCase<SettingsUserAction>): ReactNode {
  if (userAction.payload.settings.syncAlerts) {
    return `${ENABLED_SETTING} ${SYNC_ALERTS_LC}`;
  } else {
    return `${DISABLED_SETTING} ${SYNC_ALERTS_LC}`;
  }
}

export const createSettingsUserActionBuilder: UserActionBuilder = ({
  userAction,
  userProfiles,
  handleOutlineComment,
}) => ({
  build: () => {
    const action = userAction as SnakeToCamelCase<SettingsUserAction>;
    if (action?.payload?.settings?.syncAlerts !== undefined) {
      const commonBuilder = createCommonUpdateUserActionBuilder({
        userProfiles,
        userAction,
        handleOutlineComment,
        label: getSettingsLabel(action),
        icon: 'gear',
      });

      return commonBuilder.build();
    }

    // if new settings are introduced. they won't be rendered
    return [];
  },
});
