/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { SavedObjectUnsanitizedDoc } from '@kbn/core/server';

import type { PackagePolicy } from '../../../../../common';

export const httpPolicy = {
  type: 'ingest-package-policies',
  id: 'ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
  attributes: {
    name: 'Invalid http monitor with 4 minute schedule-A private location-default',
    namespace: 'default',
    package: { name: 'synthetics', title: 'Elastic Synthetics', version: '0.11.8' },
    enabled: true,
    policy_id: 'fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1',
    inputs: [
      {
        type: 'synthetics/http',
        policy_template: 'synthetics',
        enabled: true,
        streams: [
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'http',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            vars: {
              __ui: {
                value: '{"is_tls_enabled":false,"is_zip_url_tls_enabled":false}',
                type: 'yaml',
              },
              enabled: { value: true, type: 'bool' },
              type: { value: 'http', type: 'text' },
              name: { value: 'Invalid http monitor with 4 minute schedule', type: 'text' },
              schedule: { value: '"@every 4m"', type: 'text' },
              urls: { value: 'https://elastic.co', type: 'text' },
              'service.name': { value: '', type: 'text' },
              timeout: { value: '16s', type: 'text' },
              max_redirects: { value: '0', type: 'integer' },
              proxy_url: { value: '', type: 'text' },
              tags: { value: null, type: 'yaml' },
              username: { value: '', type: 'text' },
              password: { value: '', type: 'password' },
              'response.include_headers': { value: true, type: 'bool' },
              'response.include_body': { value: 'on_error', type: 'text' },
              'check.request.method': { value: 'GET', type: 'text' },
              'check.request.headers': { value: null, type: 'yaml' },
              'check.request.body': { value: null, type: 'yaml' },
              'check.response.status': { value: null, type: 'yaml' },
              'check.response.headers': { value: null, type: 'yaml' },
              'check.response.body.positive': { value: null, type: 'yaml' },
              'check.response.body.negative': { value: null, type: 'yaml' },
              'ssl.certificate_authorities': { value: null, type: 'yaml' },
              'ssl.certificate': { value: null, type: 'yaml' },
              'ssl.key': { value: null, type: 'yaml' },
              'ssl.key_passphrase': { value: null, type: 'text' },
              'ssl.verification_mode': { value: null, type: 'text' },
              'ssl.supported_protocols': { value: null, type: 'yaml' },
              location_name: { value: 'A private location', type: 'text' },
              id: { value: 'ce2f0cc6-b082-4080-9ed3-82f38743a3ed', type: 'text' },
              config_id: { value: 'ce2f0cc6-b082-4080-9ed3-82f38743a3ed', type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { value: 'ui', type: 'text' },
              'monitor.project.id': { value: null, type: 'text' },
              'monitor.project.name': { value: null, type: 'text' },
            },
            id: 'synthetics/http-http-ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              __ui: { is_tls_enabled: false, is_zip_url_tls_enabled: false },
              type: 'http',
              name: 'Invalid http monitor with 4 minute schedule',
              id: 'ce2f0cc6-b082-4080-9ed3-82f38743a3ed',
              origin: 'ui',
              'run_from.id': 'A private location',
              'run_from.geo.name': 'A private location',
              enabled: true,
              urls: 'https://elastic.co',
              schedule: '@every 4m',
              timeout: '16s',
              max_redirects: 0,
              'response.include_headers': true,
              'response.include_body': 'on_error',
              'check.request.method': 'GET',
              processors: [
                {
                  add_fields: {
                    target: '',
                    fields: {
                      'monitor.fleet_managed': true,
                      config_id: 'ce2f0cc6-b082-4080-9ed3-82f38743a3ed',
                    },
                  },
                },
              ],
            },
          },
        ],
      },
      {
        type: 'synthetics/tcp',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: false,
            data_stream: { type: 'synthetics', dataset: 'tcp' },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'tcp', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              hosts: { type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              proxy_url: { type: 'text' },
              proxy_use_local_resolver: { value: false, type: 'bool' },
              tags: { type: 'yaml' },
              'check.send': { type: 'text' },
              'check.receive': { type: 'text' },
              'ssl.certificate_authorities': { type: 'yaml' },
              'ssl.certificate': { type: 'yaml' },
              'ssl.key': { type: 'yaml' },
              'ssl.key_passphrase': { type: 'text' },
              'ssl.verification_mode': { type: 'text' },
              'ssl.supported_protocols': { type: 'yaml' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/tcp-tcp-ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
          },
        ],
      },
      {
        type: 'synthetics/icmp',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: false,
            data_stream: { type: 'synthetics', dataset: 'icmp' },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'icmp', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              wait: { value: '1s', type: 'text' },
              hosts: { type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              tags: { type: 'yaml' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/icmp-icmp-ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
          },
        ],
      },
      {
        type: 'synthetics/browser',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'browser', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              tags: { type: 'yaml' },
              'source.zip_url.url': { type: 'text' },
              'source.zip_url.username': { type: 'text' },
              'source.zip_url.folder': { type: 'text' },
              'source.zip_url.password': { type: 'password' },
              'source.inline.script': { type: 'yaml' },
              'source.project.content': { type: 'text' },
              params: { type: 'yaml' },
              playwright_options: { type: 'yaml' },
              screenshots: { type: 'text' },
              synthetics_args: { type: 'text' },
              ignore_https_errors: { type: 'bool' },
              'throttling.config': { type: 'text' },
              'filter_journeys.tags': { type: 'yaml' },
              'filter_journeys.match': { type: 'text' },
              'source.zip_url.ssl.certificate_authorities': { type: 'yaml' },
              'source.zip_url.ssl.certificate': { type: 'yaml' },
              'source.zip_url.ssl.key': { type: 'yaml' },
              'source.zip_url.ssl.key_passphrase': { type: 'text' },
              'source.zip_url.ssl.verification_mode': { type: 'text' },
              'source.zip_url.ssl.supported_protocols': { type: 'yaml' },
              'source.zip_url.proxy_url': { type: 'text' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/browser-browser-ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              __ui: null,
              type: 'browser',
              name: null,
              'run_from.id': 'Fleet managed',
              'run_from.geo.name': 'Fleet managed',
              enabled: true,
              schedule: '@every 3m',
              timeout: null,
              throttling: null,
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser.network',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            id: 'synthetics/browser-browser.network-ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser.screenshot',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            id: 'synthetics/browser-browser.screenshot-ce2f0cc6-b082-4080-9ed3-82f38743a3ed-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
        ],
      },
    ],
    is_managed: true,
    revision: 1,
    created_at: '2023-04-19T15:34:51.655Z',
    created_by: 'system',
    updated_at: '2023-04-19T15:34:51.655Z',
    updated_by: 'system',
  },
  references: [],
  coreMigrationVersion: '8.8.0',
  updated_at: '2023-04-19T15:34:51.714Z',
  created_at: '2023-04-19T15:34:51.714Z',
  typeMigrationVersion: '8.7.0',
} as unknown as SavedObjectUnsanitizedDoc<PackagePolicy>;
export const tcpPolicy = {
  type: 'ingest-package-policies',
  id: '77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
  attributes: {
    name: 'Invalid tcp monitor with 8 minute schedule-A private location-default',
    namespace: 'default',
    package: { name: 'synthetics', title: 'Elastic Synthetics', version: '0.11.8' },
    enabled: true,
    policy_id: 'fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1',
    inputs: [
      {
        type: 'synthetics/http',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: false,
            data_stream: { type: 'synthetics', dataset: 'http' },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'http', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              urls: { type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              max_redirects: { type: 'integer' },
              proxy_url: { type: 'text' },
              tags: { type: 'yaml' },
              username: { type: 'text' },
              password: { type: 'password' },
              'response.include_headers': { type: 'bool' },
              'response.include_body': { type: 'text' },
              'check.request.method': { type: 'text' },
              'check.request.headers': { type: 'yaml' },
              'check.request.body': { type: 'yaml' },
              'check.response.status': { type: 'yaml' },
              'check.response.headers': { type: 'yaml' },
              'check.response.body.positive': { type: 'yaml' },
              'check.response.body.negative': { type: 'yaml' },
              'ssl.certificate_authorities': { type: 'yaml' },
              'ssl.certificate': { type: 'yaml' },
              'ssl.key': { type: 'yaml' },
              'ssl.key_passphrase': { type: 'text' },
              'ssl.verification_mode': { type: 'text' },
              'ssl.supported_protocols': { type: 'yaml' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/http-http-77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
          },
        ],
      },
      {
        type: 'synthetics/tcp',
        policy_template: 'synthetics',
        enabled: true,
        streams: [
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'tcp',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            vars: {
              __ui: {
                value: '{"is_tls_enabled":false,"is_zip_url_tls_enabled":false}',
                type: 'yaml',
              },
              enabled: { value: true, type: 'bool' },
              type: { value: 'tcp', type: 'text' },
              name: { value: 'Invalid tcp monitor with 8 minute schedule', type: 'text' },
              schedule: { value: '"@every 8m"', type: 'text' },
              hosts: { value: 'localhost:5601', type: 'text' },
              'service.name': { value: '', type: 'text' },
              timeout: { value: '16s', type: 'text' },
              proxy_url: { value: '', type: 'text' },
              proxy_use_local_resolver: { value: false, type: 'bool' },
              tags: { value: null, type: 'yaml' },
              'check.send': { value: '', type: 'text' },
              'check.receive': { value: '', type: 'text' },
              'ssl.certificate_authorities': { value: null, type: 'yaml' },
              'ssl.certificate': { value: null, type: 'yaml' },
              'ssl.key': { value: null, type: 'yaml' },
              'ssl.key_passphrase': { value: null, type: 'text' },
              'ssl.verification_mode': { value: null, type: 'text' },
              'ssl.supported_protocols': { value: null, type: 'yaml' },
              location_name: { value: 'A private location', type: 'text' },
              id: { value: '77f25200-7cf3-450d-abfa-4f95faae1907', type: 'text' },
              config_id: { value: '77f25200-7cf3-450d-abfa-4f95faae1907', type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { value: 'ui', type: 'text' },
              'monitor.project.id': { value: null, type: 'text' },
              'monitor.project.name': { value: null, type: 'text' },
            },
            id: 'synthetics/tcp-tcp-77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              __ui: { is_tls_enabled: false, is_zip_url_tls_enabled: false },
              type: 'tcp',
              name: 'Invalid tcp monitor with 8 minute schedule',
              id: '77f25200-7cf3-450d-abfa-4f95faae1907',
              origin: 'ui',
              'run_from.id': 'A private location',
              'run_from.geo.name': 'A private location',
              enabled: true,
              hosts: 'localhost:5601',
              schedule: '@every 8m',
              timeout: '16s',
              proxy_use_local_resolver: false,
              processors: [
                {
                  add_fields: {
                    target: '',
                    fields: {
                      'monitor.fleet_managed': true,
                      config_id: '77f25200-7cf3-450d-abfa-4f95faae1907',
                    },
                  },
                },
              ],
            },
          },
        ],
      },
      {
        type: 'synthetics/icmp',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: false,
            data_stream: { type: 'synthetics', dataset: 'icmp' },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'icmp', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              wait: { value: '1s', type: 'text' },
              hosts: { type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              tags: { type: 'yaml' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/icmp-icmp-77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
          },
        ],
      },
      {
        type: 'synthetics/browser',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'browser', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              tags: { type: 'yaml' },
              'source.zip_url.url': { type: 'text' },
              'source.zip_url.username': { type: 'text' },
              'source.zip_url.folder': { type: 'text' },
              'source.zip_url.password': { type: 'password' },
              'source.inline.script': { type: 'yaml' },
              'source.project.content': { type: 'text' },
              params: { type: 'yaml' },
              playwright_options: { type: 'yaml' },
              screenshots: { type: 'text' },
              synthetics_args: { type: 'text' },
              ignore_https_errors: { type: 'bool' },
              'throttling.config': { type: 'text' },
              'filter_journeys.tags': { type: 'yaml' },
              'filter_journeys.match': { type: 'text' },
              'source.zip_url.ssl.certificate_authorities': { type: 'yaml' },
              'source.zip_url.ssl.certificate': { type: 'yaml' },
              'source.zip_url.ssl.key': { type: 'yaml' },
              'source.zip_url.ssl.key_passphrase': { type: 'text' },
              'source.zip_url.ssl.verification_mode': { type: 'text' },
              'source.zip_url.ssl.supported_protocols': { type: 'yaml' },
              'source.zip_url.proxy_url': { type: 'text' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/browser-browser-77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              __ui: null,
              type: 'browser',
              name: null,
              'run_from.id': 'Fleet managed',
              'run_from.geo.name': 'Fleet managed',
              enabled: true,
              schedule: '@every 3m',
              timeout: null,
              throttling: null,
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser.network',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            id: 'synthetics/browser-browser.network-77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser.screenshot',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            id: 'synthetics/browser-browser.screenshot-77f25200-7cf3-450d-abfa-4f95faae1907-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
        ],
      },
    ],
    is_managed: true,
    revision: 1,
    created_at: '2023-04-19T15:35:26.839Z',
    created_by: 'system',
    updated_at: '2023-04-19T15:35:26.839Z',
    updated_by: 'system',
  },
  references: [],
  coreMigrationVersion: '8.8.0',
  updated_at: '2023-04-19T15:35:26.884Z',
  created_at: '2023-04-19T15:35:26.884Z',
  typeMigrationVersion: '8.7.0',
} as unknown as SavedObjectUnsanitizedDoc<PackagePolicy>;
export const icmpPolicy = {
  type: 'ingest-package-policies',
  id: 'e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
  attributes: {
    name: 'Invalid ICMP monitor with 11 minute schedule-A private location-default',
    namespace: 'default',
    package: { name: 'synthetics', title: 'Elastic Synthetics', version: '0.11.8' },
    enabled: true,
    policy_id: 'fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1',
    inputs: [
      {
        type: 'synthetics/http',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: false,
            data_stream: { type: 'synthetics', dataset: 'http' },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'http', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              urls: { type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              max_redirects: { type: 'integer' },
              proxy_url: { type: 'text' },
              tags: { type: 'yaml' },
              username: { type: 'text' },
              password: { type: 'password' },
              'response.include_headers': { type: 'bool' },
              'response.include_body': { type: 'text' },
              'check.request.method': { type: 'text' },
              'check.request.headers': { type: 'yaml' },
              'check.request.body': { type: 'yaml' },
              'check.response.status': { type: 'yaml' },
              'check.response.headers': { type: 'yaml' },
              'check.response.body.positive': { type: 'yaml' },
              'check.response.body.negative': { type: 'yaml' },
              'ssl.certificate_authorities': { type: 'yaml' },
              'ssl.certificate': { type: 'yaml' },
              'ssl.key': { type: 'yaml' },
              'ssl.key_passphrase': { type: 'text' },
              'ssl.verification_mode': { type: 'text' },
              'ssl.supported_protocols': { type: 'yaml' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/http-http-e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
          },
        ],
      },
      {
        type: 'synthetics/tcp',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: false,
            data_stream: { type: 'synthetics', dataset: 'tcp' },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'tcp', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              hosts: { type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              proxy_url: { type: 'text' },
              proxy_use_local_resolver: { value: false, type: 'bool' },
              tags: { type: 'yaml' },
              'check.send': { type: 'text' },
              'check.receive': { type: 'text' },
              'ssl.certificate_authorities': { type: 'yaml' },
              'ssl.certificate': { type: 'yaml' },
              'ssl.key': { type: 'yaml' },
              'ssl.key_passphrase': { type: 'text' },
              'ssl.verification_mode': { type: 'text' },
              'ssl.supported_protocols': { type: 'yaml' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/tcp-tcp-e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
          },
        ],
      },
      {
        type: 'synthetics/icmp',
        policy_template: 'synthetics',
        enabled: true,
        streams: [
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'icmp',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'icmp', type: 'text' },
              name: { value: 'Invalid ICMP monitor with 11 minute schedule', type: 'text' },
              schedule: { value: '"@every 16m"', type: 'text' },
              wait: { value: '1s', type: 'text' },
              hosts: { value: '1.1.1.1', type: 'text' },
              'service.name': { value: '', type: 'text' },
              timeout: { value: '16s', type: 'text' },
              tags: { value: null, type: 'yaml' },
              location_name: { value: 'A private location', type: 'text' },
              id: { value: 'e437c11c-5cb0-42d1-966f-d2ba231550fd', type: 'text' },
              config_id: { value: 'e437c11c-5cb0-42d1-966f-d2ba231550fd', type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { value: 'ui', type: 'text' },
              'monitor.project.id': { value: null, type: 'text' },
              'monitor.project.name': { value: null, type: 'text' },
            },
            id: 'synthetics/icmp-icmp-e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              __ui: null,
              type: 'icmp',
              name: 'Invalid ICMP monitor with 11 minute schedule',
              id: 'e437c11c-5cb0-42d1-966f-d2ba231550fd',
              origin: 'ui',
              'run_from.id': 'A private location',
              'run_from.geo.name': 'A private location',
              enabled: true,
              hosts: '1.1.1.1',
              schedule: '@every 16m',
              wait: '1s',
              timeout: '16s',
              processors: [
                {
                  add_fields: {
                    target: '',
                    fields: {
                      'monitor.fleet_managed': true,
                      config_id: 'e437c11c-5cb0-42d1-966f-d2ba231550fd',
                    },
                  },
                },
              ],
            },
          },
        ],
      },
      {
        type: 'synthetics/browser',
        policy_template: 'synthetics',
        enabled: false,
        streams: [
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            vars: {
              __ui: { type: 'yaml' },
              enabled: { value: true, type: 'bool' },
              type: { value: 'browser', type: 'text' },
              name: { type: 'text' },
              schedule: { value: '"@every 3m"', type: 'text' },
              'service.name': { type: 'text' },
              timeout: { type: 'text' },
              tags: { type: 'yaml' },
              'source.zip_url.url': { type: 'text' },
              'source.zip_url.username': { type: 'text' },
              'source.zip_url.folder': { type: 'text' },
              'source.zip_url.password': { type: 'password' },
              'source.inline.script': { type: 'yaml' },
              'source.project.content': { type: 'text' },
              params: { type: 'yaml' },
              playwright_options: { type: 'yaml' },
              screenshots: { type: 'text' },
              synthetics_args: { type: 'text' },
              ignore_https_errors: { type: 'bool' },
              'throttling.config': { type: 'text' },
              'filter_journeys.tags': { type: 'yaml' },
              'filter_journeys.match': { type: 'text' },
              'source.zip_url.ssl.certificate_authorities': { type: 'yaml' },
              'source.zip_url.ssl.certificate': { type: 'yaml' },
              'source.zip_url.ssl.key': { type: 'yaml' },
              'source.zip_url.ssl.key_passphrase': { type: 'text' },
              'source.zip_url.ssl.verification_mode': { type: 'text' },
              'source.zip_url.ssl.supported_protocols': { type: 'yaml' },
              'source.zip_url.proxy_url': { type: 'text' },
              location_name: { value: 'Fleet managed', type: 'text' },
              id: { type: 'text' },
              config_id: { type: 'text' },
              run_once: { value: false, type: 'bool' },
              origin: { type: 'text' },
              'monitor.project.id': { type: 'text' },
              'monitor.project.name': { type: 'text' },
            },
            id: 'synthetics/browser-browser-e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              __ui: null,
              type: 'browser',
              name: null,
              'run_from.id': 'Fleet managed',
              'run_from.geo.name': 'Fleet managed',
              enabled: true,
              schedule: '@every 3m',
              timeout: null,
              throttling: null,
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser.network',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            id: 'synthetics/browser-browser.network-e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
          {
            enabled: true,
            data_stream: {
              type: 'synthetics',
              dataset: 'browser.screenshot',
              elasticsearch: { privileges: { indices: ['auto_configure', 'create_doc', 'read'] } },
            },
            id: 'synthetics/browser-browser.screenshot-e437c11c-5cb0-42d1-966f-d2ba231550fd-fa2e69b0-dec6-11ed-8746-c5b1a1a12ec1-default',
            compiled_stream: {
              processors: [
                { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
              ],
            },
          },
        ],
      },
    ],
    is_managed: true,
    revision: 1,
    created_at: '2023-04-19T15:35:53.763Z',
    created_by: 'system',
    updated_at: '2023-04-19T15:35:53.763Z',
    updated_by: 'system',
  },
  references: [],
  coreMigrationVersion: '8.8.0',
  updated_at: '2023-04-19T15:35:53.793Z',
  created_at: '2023-04-19T15:35:53.793Z',
  typeMigrationVersion: '8.7.0',
} as unknown as SavedObjectUnsanitizedDoc<PackagePolicy>;

export const getBrowserPolicy = (
  throttling = '5d/3u/20l',
  project: string | null = null,
  testRunId?: string,
  runOnce = false
) =>
  ({
    type: 'ingest-package-policies',
    id: '420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
    attributes: {
      name: 'https://elastic.co-A private location-default',
      namespace: 'default',
      package: { name: 'synthetics', title: 'Elastic Synthetics', version: '0.11.8' },
      enabled: true,
      policy_id: 'fe200580-dee2-11ed-933e-0f85f8c5dd40',
      inputs: [
        {
          type: 'synthetics/http',
          policy_template: 'synthetics',
          enabled: false,
          streams: [
            {
              enabled: false,
              data_stream: { type: 'synthetics', dataset: 'http' },
              vars: {
                __ui: { type: 'yaml' },
                enabled: { value: true, type: 'bool' },
                type: { value: 'http', type: 'text' },
                name: { type: 'text' },
                schedule: { value: '"@every 3m"', type: 'text' },
                urls: { type: 'text' },
                'service.name': { type: 'text' },
                timeout: { type: 'text' },
                max_redirects: { type: 'integer' },
                proxy_url: { type: 'text' },
                tags: { type: 'yaml' },
                username: { type: 'text' },
                password: { type: 'password' },
                'response.include_headers': { type: 'bool' },
                'response.include_body': { type: 'text' },
                'check.request.method': { type: 'text' },
                'check.request.headers': { type: 'yaml' },
                'check.request.body': { type: 'yaml' },
                'check.response.status': { type: 'yaml' },
                'check.response.headers': { type: 'yaml' },
                'check.response.body.positive': { type: 'yaml' },
                'check.response.body.negative': { type: 'yaml' },
                'ssl.certificate_authorities': { type: 'yaml' },
                'ssl.certificate': { type: 'yaml' },
                'ssl.key': { type: 'yaml' },
                'ssl.key_passphrase': { type: 'text' },
                'ssl.verification_mode': { type: 'text' },
                'ssl.supported_protocols': { type: 'yaml' },
                location_name: { value: 'Fleet managed', type: 'text' },
                id: { type: 'text' },
                config_id: { type: 'text' },
                run_once: { value: false, type: 'bool' },
                origin: { type: 'text' },
                'monitor.project.id': { type: 'text' },
                'monitor.project.name': { type: 'text' },
              },
              id: 'synthetics/http-http-420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
            },
          ],
        },
        {
          type: 'synthetics/tcp',
          policy_template: 'synthetics',
          enabled: false,
          streams: [
            {
              enabled: false,
              data_stream: { type: 'synthetics', dataset: 'tcp' },
              vars: {
                __ui: { type: 'yaml' },
                enabled: { value: true, type: 'bool' },
                type: { value: 'tcp', type: 'text' },
                name: { type: 'text' },
                schedule: { value: '"@every 3m"', type: 'text' },
                hosts: { type: 'text' },
                'service.name': { type: 'text' },
                timeout: { type: 'text' },
                proxy_url: { type: 'text' },
                proxy_use_local_resolver: { value: false, type: 'bool' },
                tags: { type: 'yaml' },
                'check.send': { type: 'text' },
                'check.receive': { type: 'text' },
                'ssl.certificate_authorities': { type: 'yaml' },
                'ssl.certificate': { type: 'yaml' },
                'ssl.key': { type: 'yaml' },
                'ssl.key_passphrase': { type: 'text' },
                'ssl.verification_mode': { type: 'text' },
                'ssl.supported_protocols': { type: 'yaml' },
                location_name: { value: 'Fleet managed', type: 'text' },
                id: { type: 'text' },
                config_id: { type: 'text' },
                run_once: { value: false, type: 'bool' },
                origin: { type: 'text' },
                'monitor.project.id': { type: 'text' },
                'monitor.project.name': { type: 'text' },
              },
              id: 'synthetics/tcp-tcp-420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
            },
          ],
        },
        {
          type: 'synthetics/icmp',
          policy_template: 'synthetics',
          enabled: false,
          streams: [
            {
              enabled: false,
              data_stream: { type: 'synthetics', dataset: 'icmp' },
              vars: {
                __ui: { type: 'yaml' },
                enabled: { value: true, type: 'bool' },
                type: { value: 'icmp', type: 'text' },
                name: { type: 'text' },
                schedule: { value: '"@every 3m"', type: 'text' },
                wait: { value: '1s', type: 'text' },
                hosts: { type: 'text' },
                'service.name': { type: 'text' },
                timeout: { type: 'text' },
                tags: { type: 'yaml' },
                location_name: { value: 'Fleet managed', type: 'text' },
                id: { type: 'text' },
                config_id: { type: 'text' },
                run_once: { value: runOnce, type: 'bool' },
                origin: { type: 'text' },
                'monitor.project.id': { type: 'text' },
                'monitor.project.name': { type: 'text' },
              },
              id: 'synthetics/icmp-icmp-420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
            },
          ],
        },
        {
          type: 'synthetics/browser',
          policy_template: 'synthetics',
          enabled: true,
          streams: [
            {
              enabled: true,
              data_stream: {
                type: 'synthetics',
                dataset: 'browser',
                elasticsearch: {
                  privileges: { indices: ['auto_configure', 'create_doc', 'read'] },
                },
              },
              vars: {
                __ui: {
                  value:
                    '{"script_source":{"is_generated_script":false,"file_name":""},"is_zip_url_tls_enabled":false,"is_tls_enabled":false}',
                  type: 'yaml',
                },
                enabled: { value: true, type: 'bool' },
                type: { value: 'browser', type: 'text' },
                name: { value: 'https://elastic.co', type: 'text' },
                schedule: { value: '"@every 2m"', type: 'text' },
                'service.name': { value: '', type: 'text' },
                timeout: { value: null, type: 'text' },
                tags: { value: null, type: 'yaml' },
                'source.zip_url.url': { value: '', type: 'text' },
                'source.zip_url.username': { value: '', type: 'text' },
                'source.zip_url.folder': { value: '', type: 'text' },
                'source.zip_url.password': { value: '', type: 'password' },
                'source.inline.script': {
                  value:
                    "\"step('Go to https://elastic.co', async () => {\\n  await page.goto('https://elastic.co');\\n});\"",
                  type: 'yaml',
                },
                'source.project.content': { value: '', type: 'text' },
                params: { value: '', type: 'yaml' },
                playwright_options: { value: '', type: 'yaml' },
                screenshots: { value: 'on', type: 'text' },
                synthetics_args: { value: null, type: 'text' },
                ignore_https_errors: { value: false, type: 'bool' },
                'throttling.config': { value: throttling, type: 'text' },
                'filter_journeys.tags': { value: null, type: 'yaml' },
                'filter_journeys.match': { value: null, type: 'text' },
                'source.zip_url.ssl.certificate_authorities': { value: null, type: 'yaml' },
                'source.zip_url.ssl.certificate': { value: null, type: 'yaml' },
                'source.zip_url.ssl.key': { value: null, type: 'yaml' },
                'source.zip_url.ssl.key_passphrase': { value: null, type: 'text' },
                'source.zip_url.ssl.verification_mode': { value: null, type: 'text' },
                'source.zip_url.ssl.supported_protocols': { value: null, type: 'yaml' },
                'source.zip_url.proxy_url': { value: '', type: 'text' },
                location_name: { value: 'A private location', type: 'text' },
                id: { value: '420754e9-40f2-486c-bc2e-265bafd735c5', type: 'text' },
                config_id: { value: '420754e9-40f2-486c-bc2e-265bafd735c5', type: 'text' },
                run_once: { value: runOnce, type: 'bool' },
                origin: { value: 'ui', type: 'text' },
                'monitor.project.id': { value: project, type: 'text' },
                'monitor.project.name': { value: project, type: 'text' },
                ...(testRunId ? { test_run_id: { value: testRunId, type: 'text' } } : {}),
              },
              id: 'synthetics/browser-browser-420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
              compiled_stream: {
                __ui: {
                  script_source: { is_generated_script: false, file_name: '' },
                  is_zip_url_tls_enabled: false,
                  is_tls_enabled: false,
                },
                type: 'browser',
                name: 'https://elastic.co',
                id: '420754e9-40f2-486c-bc2e-265bafd735c5',
                origin: 'ui',
                'run_from.id': 'A private location',
                'run_from.geo.name': 'A private location',
                enabled: true,
                schedule: '@every 2m',
                timeout: null,
                throttling: throttling === 'false' ? false : throttling,
                'source.inline.script':
                  "step('Go to https://elastic.co', async () => {\n  await page.goto('https://elastic.co');\n});",
                screenshots: 'on',
                processors: [
                  {
                    add_fields: {
                      target: '',
                      fields: {
                        'monitor.fleet_managed': true,
                        config_id: '420754e9-40f2-486c-bc2e-265bafd735c5',
                      },
                    },
                  },
                ],
              },
            },
            {
              enabled: true,
              data_stream: {
                type: 'synthetics',
                dataset: 'browser.network',
                elasticsearch: {
                  privileges: { indices: ['auto_configure', 'create_doc', 'read'] },
                },
              },
              id: 'synthetics/browser-browser.network-420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
              compiled_stream: {
                processors: [
                  { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
                ],
              },
            },
            {
              enabled: true,
              data_stream: {
                type: 'synthetics',
                dataset: 'browser.screenshot',
                elasticsearch: {
                  privileges: { indices: ['auto_configure', 'create_doc', 'read'] },
                },
              },
              id: 'synthetics/browser-browser.screenshot-420754e9-40f2-486c-bc2e-265bafd735c5-fe200580-dee2-11ed-933e-0f85f8c5dd40-default',
              compiled_stream: {
                processors: [
                  { add_fields: { target: '', fields: { 'monitor.fleet_managed': true } } },
                ],
              },
            },
          ],
        },
      ],
      is_managed: true,
      revision: 1,
      created_at: '2023-04-19T18:55:35.126Z',
      created_by: 'system',
      updated_at: '2023-04-19T18:55:35.126Z',
      updated_by: 'system',
    },
    references: [],
    coreMigrationVersion: '8.8.0',
    updated_at: '2023-04-19T18:55:35.250Z',
    created_at: '2023-04-19T18:55:35.250Z',
    typeMigrationVersion: '8.7.0',
  } as unknown as SavedObjectUnsanitizedDoc<PackagePolicy>);
