/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import type { KibanaRequest } from '@kbn/core/server';
import type { ElasticsearchClient } from '@kbn/core/server';

import type { AgentPolicy } from '../../common';

import { generateEnrollmentAPIKey, deleteEnrollmentApiKeyForAgentPolicyId } from './api_keys';
import { unenrollForAgentPolicyId } from './agents';
import { agentPolicyService } from './agent_policy';
import { appContextService } from './app_context';

const fakeRequest = {
  headers: {},
  getBasePath: () => '',
  path: '/',
  route: { settings: {} },
  url: {
    href: '/',
  },
  raw: {
    req: {
      url: '/',
    },
  },
} as unknown as KibanaRequest;

export async function agentPolicyUpdateEventHandler(
  esClient: ElasticsearchClient,
  action: string,
  agentPolicyId: string,
  options?: { skipDeploy?: boolean; spaceId?: string; agentPolicy?: AgentPolicy | null }
) {
  // `soClient` from ingest `appContextService` is used to create policy change actions
  // to ensure encrypted SOs are handled correctly
  const internalSoClient = options?.spaceId
    ? appContextService.getInternalUserSOClientForSpaceId(options?.spaceId)
    : appContextService.getInternalUserSOClient(fakeRequest);

  if (action === 'created') {
    await generateEnrollmentAPIKey(internalSoClient, esClient, {
      name: 'Default',
      agentPolicyId,
      forceRecreate: true,
    });
    if (!options?.skipDeploy) {
      await agentPolicyService.deployPolicy(internalSoClient, agentPolicyId, options?.agentPolicy);
    }
  }

  if (action === 'updated') {
    await agentPolicyService.deployPolicy(internalSoClient, agentPolicyId, options?.agentPolicy);
  }

  if (action === 'deleted') {
    await unenrollForAgentPolicyId(internalSoClient, esClient, agentPolicyId);
    await deleteEnrollmentApiKeyForAgentPolicyId(esClient, agentPolicyId);
  }
}
