/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import './frame_layout.scss';

import React from 'react';
import { EuiScreenReaderOnly, EuiFlexGroup, EuiFlexItem, EuiPage, EuiPageBody } from '@elastic/eui';
import { i18n } from '@kbn/i18n';
import classNames from 'classnames';
import { useLensSelector, selectIsFullscreenDatasource } from '../../state_management';

export interface FrameLayoutProps {
  dataPanel: React.ReactNode;
  configPanel?: React.ReactNode;
  suggestionsPanel?: React.ReactNode;
  workspacePanel?: React.ReactNode;
  bannerMessages?: React.ReactNode;
}

export function FrameLayout(props: FrameLayoutProps) {
  const isFullscreen = useLensSelector(selectIsFullscreenDatasource);

  return (
    <EuiFlexGroup direction="column" responsive={false} gutterSize="none" alignItems="stretch">
      {props.bannerMessages ? (
        <EuiFlexItem grow={false}>
          <aside aria-labelledby="bannerMessagesId">
            <EuiScreenReaderOnly>
              <h2 id="bannerMessagesId">
                {i18n.translate('xpack.lens.section.bannerMessagesLabel', {
                  defaultMessage: 'Deprecation messages',
                })}
              </h2>
            </EuiScreenReaderOnly>
            {props.bannerMessages}
          </aside>
        </EuiFlexItem>
      ) : null}
      <EuiFlexItem grow={true} className="lnsFrameLayout__wrapper">
        <EuiPage
          paddingSize="none"
          className={classNames('lnsFrameLayout', {
            'lnsFrameLayout-isFullscreen': isFullscreen,
          })}
        >
          <EuiPageBody
            restrictWidth={false}
            className="lnsFrameLayout__pageContent"
            aria-labelledby="lns_ChartTitle"
          >
            <section
              className={'lnsFrameLayout__sidebar lnsFrameLayout__sidebar--left hide-for-sharing'}
              aria-labelledby="dataPanelId"
            >
              <EuiScreenReaderOnly>
                <h2 id="dataPanelId">
                  {i18n.translate('xpack.lens.section.dataPanelLabel', {
                    defaultMessage: 'Data panel',
                  })}
                </h2>
              </EuiScreenReaderOnly>
              {props.dataPanel}
            </section>
            <section
              className={classNames('lnsFrameLayout__pageBody', {
                'lnsFrameLayout__pageBody-isFullscreen': isFullscreen,
              })}
              aria-labelledby="workspaceId"
            >
              <EuiScreenReaderOnly>
                <h2 id="workspaceId">
                  {i18n.translate('xpack.lens.section.workspaceLabel', {
                    defaultMessage: 'Visualization workspace',
                  })}
                </h2>
              </EuiScreenReaderOnly>
              {props.workspacePanel}
              <div className="lnsFrameLayout__suggestionPanel hide-for-sharing">
                {props.suggestionsPanel}
              </div>
            </section>
            <section
              className={classNames(
                'lnsFrameLayout__sidebar lnsFrameLayout__sidebar--right',
                'hide-for-sharing',
                {
                  'lnsFrameLayout__sidebar-isFullscreen': isFullscreen,
                }
              )}
              aria-labelledby="configPanel"
            >
              <EuiScreenReaderOnly>
                <h2 id="configPanel">
                  {i18n.translate('xpack.lens.section.configPanelLabel', {
                    defaultMessage: 'Config panel',
                  })}
                </h2>
              </EuiScreenReaderOnly>
              {props.configPanel}
            </section>
          </EuiPageBody>
        </EuiPage>
      </EuiFlexItem>
    </EuiFlexGroup>
  );
}
