/*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0; you may not use this file except in compliance with the Elastic License
 * 2.0.
 */

import { getTimeUnitLabel } from './get_time_unit_label';
import { TIME_UNITS } from '../constants';

export const getTimeOptions = (unitSize: string) =>
  Object.entries(TIME_UNITS).map(([_key, value]) => {
    return {
      text: getTimeUnitLabel(value, unitSize),
      value,
    };
  });

interface TimeFieldOptions {
  text: string;
  value: string;
}

export const getTimeFieldOptions = (
  fields: Array<{ type: string; name: string }>
): TimeFieldOptions[] => {
  const options: TimeFieldOptions[] = [];

  fields.forEach((field: { type: string; name: string }) => {
    if (field.type === 'date') {
      options.push({
        text: field.name,
        value: field.name,
      });
    }
  });
  return options;
};
